@@ -1,28 +1,16 @@
-import asyncio
-
 import pytest
-import websockets
 
-from aiorpcx import *
+from aiorpcx import connect_ws, NetAddress, serve_ws
 
 from test_session import MyServerSession
 
 
-@pytest.fixture
-def ws_server(unused_tcp_port, event_loop):
-    coro = serve_ws(MyServerSession, 'localhost', unused_tcp_port, loop=event_loop)
-    server = event_loop.run_until_complete(coro)
+@pytest.fixture(scope="function")
+async def ws_server(unused_tcp_port):
+    server = await serve_ws(MyServerSession, 'localhost', unused_tcp_port)
     yield f'ws://localhost:{unused_tcp_port}'
-    if hasattr(asyncio, 'all_tasks'):
-        tasks = asyncio.all_tasks(event_loop)
-    else:
-        tasks = asyncio.Task.all_tasks(loop=event_loop)
-    async def close_all():
-        server.close()
-        await server.wait_closed()
-        if tasks:
-            await asyncio.wait(tasks)
-    event_loop.run_until_complete(close_all())
+    server.close()
+    await server.wait_closed()
 
 
 @pytest.mark.filterwarnings("ignore:'with .*:DeprecationWarning")
